#!/usr/bin/env python
"""
pbs
==================

django-prescribed-burn-system (pbs) is a system for managing prescribed
burning in Western Australia. It is currently deployed in production within
the Department of Parks and Wildlife.

:copyright: (c) 2013 Department of Parks & Wildlife, see AUTHORS
            for more details.
:license: BSD 3-Clause, see LICENSE for more details.
"""
from setuptools import setup, find_packages
from pkg_resources import parse_version

import os

# Hack to prevent stupid "TypeError: 'NoneType' object is not callable" error
# in multiprocessing/util.py _exit_function when running `python
# setup.py test` (see
# http://www.eby-sarna.com/pipermail/peak/2010-May/003357.html)
for m in ('multiprocessing', 'billiard'):
    try:
        __import__(m)
    except ImportError:
        pass


# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

tests_require = [
    'django_nose',
    'model_mommy',
    'six==1.3.0',
]


django = 'django>=1.5'
if os.environ.get('DJANGO'):
    if parse_version(os.environ.get('DJANGO')) >= parse_version('1.5'):
        django = 'django=={0}'.format(os.environ.get('DJANGO'))
    else:
        raise Exception('django-prescribed-burn-system requires django>=1.5')

django = 'django==1.5'  # TODO, TODO: e.g. django.contrib.markup got deprecated

install_requires = [
    django,
    'dj_database_url',
    'python-dateutil',
    'python-ldap',
    'django-auth-ldap',
    'django-redis-cache',
    'django-admin-enhancer',
    'django-select2',
    'django-chosen',
    'django-smart-selects',
    'django_compressor',
    'django-dtpanel-htmltidy',
    'django-registration',
    'django-crispy-forms',
    'django-markdown',
    'django-swingers>1.0.3',
    'coverage',
    'pyflakes',
    'pep8',
    'pylint',
    'mock',
    'selenium',
    'envoy',
    'fuzzywuzzy',
    'joblib',
    'unicodecsv',
    'gunicorn',
    'Pillow',
    'PyPDF2',
]


version = __import__('pbs').get_version()

setup(
    name='django-prescribed-burn-system',
    version=version,
    author=('Nick Sandford, Adon Metcalfe, Ashley Felton, Wilson Cheung,'
            'Tomas Krajca'),
    author_email=('Nick.Sandford@DPaW.wa.gov.au '
                  'Adon Metcalfe@DPaW.wa.gov.au '
                  'Ashley Felton@DPaW.wa.gov.au '
                  'Wilson Cheung@DPaW.wa.gov.au '
                  'Tomas Krajca@DPaW.wa.gov.au'),
    url='https://github.com/dpaw2/django-prescribed-burn-system/',
    description=('django-prescribed-burn-system (pbs) is a system for managing'
                 ' prescribed burning in Western Australia. It is currently '
                 'deployed in production within the Department of Parks and '
                 'Wildlife.'),
    packages=find_packages(exclude=['docs']),
    zip_safe=False,
    dependency_links = [
        'hg+https://bitbucket.org/dpaw/django-swingers#egg=django-swingers-1.0.4',
    ],
    install_requires=install_requires,
    tests_require=tests_require,
    test_suite='pbs.tests.runtests',
    scripts=[],
    license='BSD License',
    include_package_data=True,
    classifiers=[
        'Framework :: Django',
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
    ],
)
